@@ -1,8 +1,10 @@
+require 'rubygems/command'
+require 'rubygems/commands/query_command'
+
 module Gem
   module Commands
 
     class SearchCommand < QueryCommand
-      include CommandAids
 
       def initialize
         super(
@@ -12,18 +14,18 @@ module Gem
         remove_option('--name-matches')
       end
 
-      def defaults_str
+      def arguments # :nodoc:
+        "STRING        fragment of gem name to search for"
+      end
+
+      def defaults_str # :nodoc:
         "--local --no-details"
       end
 
-      def usage
+      def usage # :nodoc:
         "#{program_name} [STRING]"
       end
 
-      def arguments
-        "STRING   fragment of gem name to look for"
-      end
-
       def execute
         string = get_one_optional_argument
         options[:name] = /#{string}/i
@@ -32,4 +34,4 @@ module Gem
     end
     
   end
-end
\ No newline at end of file
+end
